anchors(formula, data, method = c("B","C"),
options=anchors.options(),
subset, combn = FALSE, na.action = na.omit)anchors.options;subset.summary.anchors function.[object Object],[object Object],[object Object],[object Object]
cpolr model that was used to estimate how to
allocate interval rank values to scalar rank valueschopit as with anchors (i.e., drop cases with any
missing responses or missing cpolr values), and vise versa (i.e.,
also drop any case with missing values in the tau=,
tau1= formulae), then the user should use the same list of
formula for all methods and use the option
anchors.options(delete="maximal"). See example below. Only options relevant to anchors are discussed here.
The named list() of formulas may include
self: LHS self-response variable; RHS is simply 1 (needed to define a formula); actually anything can be put on the RHS, and it will not by default be used.
vign: vignette responses, bound together by cbind (as in glm binomial syntax), with ONLY '~ 1' as RHS of equation (formulas must have RHS).
cpolr: OPTIONAL. linear predictors used by the censored ordered
probit, cpolr, model to
break ties in
rank based models, method="B" or "C". Default is cpolr = ~ 1 (i.e.,
an intercept only).
Example:
fo <- list(self = xsayself ~ 1, vign = cbind(xsay3,xsay1) ~ 1, cpolr = ~ age )
NOTE: one can also use a single formula as a short hand: specifying
fo <- self ~ vign1 + vign2
is equivalent to
fo <- list(self = self ~ 1 vign = cbind(vign1,vign2) ~ 1, cpolr= ~ 1)
All of the response variables must be in the form of consequetive non-negative
numeric integers, i.e., 1, 2, ... K.
** anchors currently does not support factor responses.**
The method="B" and "C" requires that cases with any response
that is missing be dropped. Any cases with missing values
the covariates specified in the cpolr= formula are also
dropped. BUT by default these methods ignore missing values in the
covariates specified by tau=, tau1=, or the right hand
side of self=.
Wand, Jonathan. (2007)
"Credible Comparisons Using Interpersonally Incomparable Data:
Ranking self-evaluations relative to anchoring vignettes or
other common survey questions".
copy at
anchors.order,
anchors.options,
chopit,data(mexchn)
fo <- list(self = xsayself ~ age,
vign = cbind(xsay3,xsay1) ~ 1,
tau = ~ age + china,
tau1 = ~ age + china + male,
cpolr= ~ china + male
)
a2 <- anchors(fo, data = mexchn, method="B")
summary(a2)
a3 <- anchors(fo, data = mexchn, method="C")
summary(a3)Run the code above in your browser using DataLab