Learn R Programming

anchors (version 3.0-7)

anchors.combn: Calculate known minimum or estimated entropy for survey vignettes

Description

Calculate known minimum or estimated entropy for survey vignettes

Usage

anchors.combn(adata, fdata, type, options)

Arguments

adata
object of class anchors.data
fdata
data frame from which adata was built
type
either "B" or "C", specifying nonparametric method
options
object of class anchors.options

Value

  • A list of class anchors.combn, containing elements
  • vign.ranka matrix with columns corresponding to the vignette selection, the estimated entropy (if covar is specified), the known entropy, the number of cases with intervals for that particular vignette selection, and 2J+1 number of categories for the given vignettes.
  • Nthe number of observations after list-wise deletion
  • selfa character string containing the variable name of the self-response question
  • vigna character vector containing the variable names of the vignette questions. The first element of the vector corresponds to vignette 1, the second vignette 2, etc.

References

Wand, Jonathan; Gary King; and Olivia Lau. (2007) ``Anchors: Software for Anchoring Vignettes''. Journal of Statistical Software. Forthcoming. copy at http://wand.stanford.edu/research/anchors-jss.pdf

Wand, Jonathan and Gary King. (2007) Anchoring Vignetttes in R: A (different kind of) Vignette copy at http://wand.stanford.edu/anchors/doc/anchors.pdf

Gary King and Jonathan Wand. "Comparing Incomparable Survey Responses: New Tools for Anchoring Vignettes," Political Analysis, 15, 1 (Winter, 2007): Pp. 46-66, copy at http://gking.harvard.edu/files/abs/c-abs.shtml.

See Also

anchors

Examples

Run this code
## ra <- anchors( fo, data, method="C", combn=TRUE)
  ## summary( ra , combn = "Minimum" )
  ## plot( ra, type="xy" , xy =  c("minimum","intervals") )

Run the code above in your browser using DataLab