Learn R Programming

anchors (version 3.0-7)

fitted.anchors.rank: Fitted values of non-parametric models

Description

Fitted values of non-parametric models

Usage

## S3 method for class 'anchors.rank':
fitted(object, ..., ties = c("omit", "uniform", "cpolr",
                 "minentropy"), average = FALSE, unconditional = FALSE)

Arguments

object
object of class anchors.rank.
...
required for S3, but any other options will be ignored.
ties
method for allocating ties/interval valued cases to a scalar value
average
a logical value. See values below for more details.
unconditional
Set to TRUE if you submit an anchors.object AND want the unconditional probabilities returned. One case that you would submit a anchors.rank object is if you did subsetting for the anchors object but not for the cpolr object, and want the inte

Value

  • If average = FALSE, a matrix of predicted probabilities with rows corresponding to observations, and columns corresponding to categories.

    If average = TRUE, the matrix of predicted probabilities (conditional or unconditional) is summarized to a vector.

References

Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S. 4th edition. Springer.

Wand, Jonathan; Gary King; and Olivia Lau. (2007) ``Anchors: Software for Anchoring Vignettes''. Journal of Statistical Software. Forthcoming. copy at http://wand.stanford.edu/research/anchors-jss.pdf

Wand, Jonathan and Gary King. (2007) Anchoring Vignetttes in R: A (different kind of) Vignette copy at http://wand.stanford.edu/anchors/doc/anchors.pdf

Gary King and Jonathan Wand. "Comparing Incomparable Survey Responses: New Tools for Anchoring Vignettes," Political Analysis, 15, 1 (Winter, 2007): Pp. 46-66, copy at http://gking.harvard.edu/files/abs/c-abs.shtml.

See Also

anchors, cpolr

Examples

Run this code
## Basic usage: see anchors

Run the code above in your browser using DataLab